
.. _metrics:

.. currentmodule:: jgrapht.metrics

Metrics
*******

Certain graph metrics such as the diameter of a graph can be computed using the following functions.

.. automodule:: jgrapht.metrics
   :members:
